Function which converts the supplied regionmapping file to a transformation
matrix which then can be used for aggregation with
speed_aggregate.
Arguments
- rel
file name of a region mapping (".csv" as file ending, ";" used as separator and with columns containing the region names) or a mapping matrix (matrix with region names in columns)
- from
Name of the first column to be used (if not set the first or second column will be used)
- to
Name of the second column to be used (if not set the second or third column will be used)